@@ -24,13 +24,14 @@ from PyQt5.QtCore import QRect, Qt
 from PyQt5.QtGui import QGuiApplication, QCursor
 import numpy as np
 import matplotlib.patches as mpatches
-import matplotlib.pyplot as plt
+from matplotlib.colors import LinearSegmentedColormap
 from PIL import Image
 
 # local import
 from gui.utilities import toolsQtWidget
 from gui.widgets import hemisphere_ui
 from gui.extWindows.hemisphereWext import HemisphereWindowExt
+from base.transform import diffModulusAbs
 
 
 class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
@@ -67,38 +68,8 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         self.ui.setupUi(self)
         self.mutexDraw = PyQt5.QtCore.QMutex()
         self.operationMode = 'normal'
-        self.statusDAT = None
-
-        self.MODE = dict(
-            normal=dict(horMarker='None',
-                        horColor=self.M_BLUE,
-                        buildPColor=self.M_GREEN_H,
-                        starSize=6,
-                        starColor=self.M_YELLOW_L,
-                        starAnnColor=self.M_WHITE_L),
-
-            build=dict(horMarker='None',
-                       horColor=self.M_BLUE,
-                       buildPColor=self.M_PINK_H,
-                       starSize=6,
-                       starColor=self.M_YELLOW_L,
-                       starAnnColor=self.M_WHITE_L),
-
-            horizon=dict(horMarker='o',
-                         horColor=self.M_PINK_H,
-                         buildPColor=self.M_GREEN_L,
-                         starSize=6,
-                         starColor=self.M_YELLOW_L,
-                         starAnnColor=self.M_WHITE_L),
-
-            star=dict(horMarker='None',
-                      horColor=self.M_BLUE1,
-                      buildPColor=self.M_GREEN_L,
-                      starSize=12,
-                      starColor=self.M_YELLOW_H,
-                      starAnnColor=self.M_WHITE_H)
-        )
-
+        self.MODE = None
+        self.setModeColors()
         self.pointerAltAz = None
         self.pointerDome = None
         self.pointsBuild = None
@@ -157,6 +128,7 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         self.ui.checkUseTerrain.setChecked(config.get('useTerrain', False))
         self.ui.terrainAlpha.setValue(config.get('terrainAlpha', 0.35))
         self.ui.azimuthShift.setValue(config.get('azimuthShift', 0))
+        self.ui.altitudeShift.setValue(config.get('altitudeShift', 0))
 
         terrainFile = self.app.mwGlob['configDir'] + '/terrain.jpg'
         if not os.path.isfile(terrainFile):
@@ -169,10 +141,9 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         img = img.resize((1440, 360))
         img = img.transpose(Image.FLIP_TOP_BOTTOM)
 
-        self.imageTerrain = Image.new('L', (2880, 360))
-        self.imageTerrain.paste(img)
-        self.imageTerrain.paste(img, (1440, 0))
-
+        self.imageTerrain = Image.new('L', (2880, 480), 128)
+        self.imageTerrain.paste(img, (0, 60))
+        self.imageTerrain.paste(img, (1440, 60))
         return True
 
     def storeConfig(self):
@@ -183,8 +154,8 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
             self.app.config['hemisphereW'] = {}
 
         config = self.app.config['hemisphereW']
-        config['winPosX'] = self.pos().x()
-        config['winPosY'] = self.pos().y()
+        config['winPosX'] = max(self.pos().x(), 0)
+        config['winPosY'] = max(self.pos().y(), 0)
         config['height'] = self.height()
         config['width'] = self.width()
         config['checkShowSlewPath'] = self.ui.checkShowSlewPath.isChecked()
@@ -196,6 +167,7 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         config['useTerrain'] = self.ui.checkUseTerrain.isChecked()
         config['terrainAlpha'] = self.ui.terrainAlpha.value()
         config['azimuthShift'] = self.ui.azimuthShift.value()
+        config['altitudeShift'] = self.ui.altitudeShift.value()
         return True
 
     def closeEvent(self, closeEvent):
@@ -226,6 +198,7 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         self.ui.checkShowAlignStar.clicked.disconnect(self.drawHemisphere)
         self.ui.checkUseTerrain.clicked.disconnect(self.drawHemisphere)
         self.ui.azimuthShift.valueChanged.disconnect(self.drawHemisphere)
+        self.ui.altitudeShift.valueChanged.disconnect(self.drawHemisphere)
         self.ui.terrainAlpha.valueChanged.disconnect(self.drawHemisphere)
 
         self.ui.showPolar.clicked.disconnect(self.togglePolar)
@@ -234,11 +207,7 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         self.app.dome.signals.azimuth.disconnect(self.updateDome)
         self.app.dome.signals.deviceDisconnected.disconnect(self.updateDome)
         self.app.dome.signals.serverDisconnected.disconnect(self.updateDome)
-
-        plt.close(self.hemisphereMat.figure)
-        plt.close(self.polarMat.figure)
-        plt.close(self.hemisphereMatMove.figure)
-        plt.close(self.polarMatMove.figure)
+        self.app.colorChange.disconnect(self.colorChange)
         QGuiApplication.setOverrideCursor(QCursor(Qt.ArrowCursor))
 
         super().closeEvent(closeEvent)
@@ -248,7 +217,6 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         :param event:
         :return:
         """
-
         geometry = self.ui.hemisphere.geometry()
         newGeometry = QRect(0, 0, geometry.width(), geometry.height())
         self.ui.hemisphereMove.setGeometry(newGeometry)
@@ -288,7 +256,9 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         self.ui.checkPolarAlignment.clicked.connect(self.setOperationMode)
         self.ui.checkUseTerrain.clicked.connect(self.drawHemisphere)
         self.ui.azimuthShift.valueChanged.connect(self.drawHemisphere)
+        self.ui.altitudeShift.valueChanged.connect(self.drawHemisphere)
         self.ui.terrainAlpha.valueChanged.connect(self.drawHemisphere)
+        self.app.colorChange.connect(self.colorChange)
 
         self.ui.showPolar.clicked.connect(self.togglePolar)
         self.ui.addPositionToHorizon.clicked.connect(self.addHorizonPointManual)
@@ -299,6 +269,76 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         self.show()
         return True
 
+    def setModeColors(self):
+        """
+        :return:
+        """
+        self.MODE = dict(
+            normal=dict(horMarker='None',
+                        horColor=self.M_BLUE,
+                        buildPColor=self.M_GREEN,
+                        starSize=6,
+                        starColor=self.M_YELLOW1,
+                        starAnnColor=self.M_WHITE1),
+
+            build=dict(horMarker='None',
+                       horColor=self.M_BLUE,
+                       buildPColor=self.M_PINK,
+                       starSize=6,
+                       starColor=self.M_YELLOW1,
+                       starAnnColor=self.M_WHITE1),
+
+            horizon=dict(horMarker='o',
+                         horColor=self.M_PINK,
+                         buildPColor=self.M_GREEN1,
+                         starSize=6,
+                         starColor=self.M_YELLOW1,
+                         starAnnColor=self.M_WHITE1),
+
+            star=dict(horMarker='None',
+                      horColor=self.M_BLUE1,
+                      buildPColor=self.M_GREEN1,
+                      starSize=12,
+                      starColor=self.M_YELLOW,
+                      starAnnColor=self.M_WHITE)
+        )
+        return True
+
+    def colorChange(self):
+        """
+        :return:
+        """
+        self.setStyleSheet(self.mw4Style)
+        self.setModeColors()
+        self.drawHemisphere()
+        return True
+
+    def calculateRelevance(self, alt=None, az=None):
+        """
+        :param alt:
+        :param az:
+        :return:
+        """
+        isNorth = self.app.mount.obsSite.location.latitude.degrees > 0
+        altFak = 1 - np.minimum(np.abs(alt - 30), 35) / 35
+        if isNorth:
+            azFak = 1 - np.minimum(diffModulusAbs(0, az - 180, 360), 75) / 75
+        else:
+            azFak = 1 - np.minimum(diffModulusAbs(0, az, 360), 75) / 75
+        sumFak = np.sqrt(altFak * azFak)
+        return sumFak
+
+    def selectFontParam(self, relevance):
+        """
+        :param relevance:
+        :return: calculated color
+        """
+        colors = [self.M_RED, self.M_YELLOW, self.M_GREEN]
+        cMap = LinearSegmentedColormap.from_list("MyMap", colors)
+        color = cMap(relevance)
+        size = 10 + int(relevance * 5)
+        return color, size
+
     def togglePolar(self):
         """
         :return: success
@@ -352,7 +392,6 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         if obsSite.Alt is None or obsSite.Az is None:
             self.pointerAltAz.set_visible(False)
             return False
-
         else:
             self.pointerAltAz.set_visible(True)
 
@@ -372,7 +411,6 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         if obsSite.Alt is None or obsSite.Az is None:
             self.pointerPolarAltAz.set_visible(False)
             return False
-
         else:
             self.pointerPolarAltAz.set_visible(True)
 
@@ -392,7 +430,6 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         """
         if self.pointerDome is None:
             return False
-
         if not isinstance(azimuth, (int, float)):
             self.pointerDome.set_visible(False)
             return False
@@ -413,7 +450,6 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
             color = self.MODE[self.operationMode]['buildPColor']
             mSize = 9
             annotationText = f'{index + 1:2d}'
-
         else:
             marker = '$\u2714$'
             color = self.M_YELLOW
@@ -483,13 +519,19 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         self.starsAlignAnnotate = list()
 
         for alt, az, name in zip(hip.alt, hip.az, hip.name):
+            if self.operationMode == 'star':
+                rel = self.calculateRelevance(alt=alt, az=az)
+                fontColor, fontSize = self.selectFontParam(rel)
+            else:
+                fontSize = 12
+                fontColor = self.M_WHITE1
             annotation = axes.annotate(name,
                                        xy=(az, alt),
                                        xytext=(2, 2),
                                        textcoords='offset points',
                                        xycoords='data',
-                                       color=self.M_WHITE_L,
-                                       fontsize=12,
+                                       color=fontColor,
+                                       fontsize=fontSize,
                                        zorder=30,
                                        clip_on=True,
                                        )
@@ -528,11 +570,11 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
             azF = np.radians(range(0, 361, 5))
             altF = np.interp(azF, az, alt)
 
+            axes.set_facecolor(f'{self.M_GREY}80')
             axes.fill(azF,
                       90 - altF,
-                      color=self.M_TRANS,
-                      alpha=0.5,
-                      zorder=0)
+                      color=self.M_BACK,
+                      zorder=-10)
 
             axes.plot(az,
                       90 - alt,
@@ -557,7 +599,7 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
             azF = np.concatenate([[0], [0], az, [360], [360]])
             axes.fill(azF,
                       altF,
-                      color=self.M_GREY_LL,
+                      color=self.M_GREY,
                       alpha=0.5,
                       zorder=0)
 
@@ -586,14 +628,12 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         :return:
         """
         points = self.app.data.buildP
-
         if not points:
             return False
 
         if polar:
             self.pointsPolarBuild = list()
             self.pointsPolarBuildAnnotate = list()
-
         else:
             self.pointsBuild = list()
             self.pointsBuildAnnotate = list()
@@ -610,7 +650,6 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
                     axes.plot(np.radians((points[index - 1][1], points[index][1])),
                               (90 - points[index - 1][0], 90 - points[index][0]),
                               ls=':', lw=1, color=self.M_WHITE, zorder=40)
-
                 else:
                     axes.plot((points[index - 1][1], points[index][1]),
                               (points[index - 1][0], points[index][0]),
@@ -625,7 +664,6 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
                                zorder=40,
                                )
                 self.pointsPolarBuild.append(p)
-
             else:
                 p, = axes.plot(az, alt,
                                marker=marker,
@@ -645,7 +683,6 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
                                            zorder=40,
                                            )
                 self.pointsPolarBuildAnnotate.append(annotation)
-
             else:
                 annotation = axes.annotate(text,
                                            xy=(az, alt),
@@ -679,7 +716,7 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
                                             markersize=1,
                                             fillstyle='none',
                                             zorder=20,
-                                            color=self.M_WHITE_L)
+                                            color=self.M_WHITE1)
         else:
             self.celestialPath, = axes.plot(az,
                                             alt,
@@ -687,7 +724,7 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
                                             markersize=1,
                                             fillstyle='none',
                                             zorder=20,
-                                            color=self.M_WHITE_L)
+                                            color=self.M_WHITE1)
         return True
 
     def staticMeridianLimits(self, axes=None):
@@ -697,7 +734,6 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         """
         slew = self.app.mount.setting.meridianLimitSlew
         track = self.app.mount.setting.meridianLimitTrack
-
         if slew is None or track is None:
             return False
 
@@ -713,7 +749,7 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
                                                 2 * track,
                                                 90,
                                                 zorder=10,
-                                                color=self.M_YELLOW_L,
+                                                color=self.M_YELLOW1,
                                                 alpha=0.5)
         axes.add_patch(self.meridianTrack)
         return True
@@ -726,13 +762,11 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         """
         if self.app.mount.setting.horizonLimitHigh is not None:
             high = self.app.mount.setting.horizonLimitHigh
-
         else:
             high = 90
 
         if self.app.mount.setting.horizonLimitLow is not None:
             low = self.app.mount.setting.horizonLimitLow
-
         else:
             low = 0
 
@@ -764,9 +798,11 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         if not self.imageTerrain:
             return False
 
-        shift = self.ui.azimuthShift.value()
+        shiftAz = self.ui.azimuthShift.value()
+        shiftAlt = self.ui.altitudeShift.value()
         alpha = self.ui.terrainAlpha.value()
-        imgF = self.imageTerrain.crop((4 * shift, 0, 1440 + 4 * shift, 360))
+        imgF = self.imageTerrain.crop((4 * shiftAz, 60 + shiftAlt * 2,
+                                       1440 + 4 * shiftAz, 420 + shiftAlt * 2))
         (w, h) = imgF.size
         img = list(imgF.getdata())
         img = np.array(img).reshape((h, w))
@@ -809,7 +845,6 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
 
             if self.ui.checkUseTerrain.isChecked():
                 self.staticTerrainMask(axes=axes, polar=polar)
-
         else:
             if self.ui.checkUseHorizon.isChecked():
                 self.staticHorizon(axes=axes)
@@ -843,7 +878,7 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         if polar:
             self.pointerPolarAltAz, = axes.plot(np.radians(180), 45,
                                                 zorder=10,
-                                                color=self.M_PINK_H,
+                                                color=self.M_PINK,
                                                 marker=self.markerAltAz(),
                                                 markersize=25,
                                                 linestyle='none',
@@ -851,11 +886,10 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
                                                 clip_on=False,
                                                 visible=False,
                                                 )
-
         else:
             self.pointerAltAz, = axes.plot(180, 45,
                                            zorder=10,
-                                           color=self.M_PINK_H,
+                                           color=self.M_PINK,
                                            marker=self.markerAltAz(),
                                            markersize=25,
                                            linestyle='none',
@@ -863,12 +897,11 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
                                            clip_on=False,
                                            visible=False,
                                            )
-
             self.pointerDome = mpatches.Rectangle((165, 1),
                                                   30,
                                                   88,
                                                   zorder=0,
-                                                  color=self.M_GREY_MID,
+                                                  color=self.M_GREY,
                                                   lw=3,
                                                   clip_on=True,
                                                   fill=True,
@@ -895,21 +928,27 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         self.starsAlign, = axes.plot(hip.az,
                                      hip.alt,
                                      marker=self.markerStar(),
-                                     markersize=7,
+                                     markersize=8,
                                      linestyle='None',
                                      color=self.MODE[self.operationMode]['starColor'],
                                      zorder=30,
                                      )
 
         for alt, az, name in zip(hip.alt, hip.az, hip.name):
+            if self.operationMode == 'star':
+                rel = self.calculateRelevance(alt=alt, az=az)
+                fontColor, fontSize = self.selectFontParam(rel)
+            else:
+                fontSize = 12
+                fontColor = self.M_WHITE1
             annotation = axes.annotate(name,
                                        xy=(az, alt),
                                        xytext=(2, 2),
                                        textcoords='offset points',
                                        xycoords='data',
-                                       color=self.M_WHITE_L,
+                                       color=fontColor,
                                        zorder=30,
-                                       fontsize=12,
+                                       fontsize=fontSize,
                                        clip_on=True,
                                        )
             self.starsAlignAnnotate.append(annotation)
@@ -923,7 +962,7 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
         layers of transparent widgets for static content, moving content and star
         maps. this is mainly done to get a reasonable performance when redrawing
         the canvas. in addition it initializes the objects for points markers,
-        patches, lines etc. for making the window nice and user friendly. the
+        patches, lines etc. for making the window nice and user-friendly. the
         user interaction on the hemisphere windows is done by the event handler
         of matplotlib itself implementing an on Mouse handler, which takes care
         of functions.
@@ -966,7 +1005,6 @@ class HemisphereWindow(toolsQtWidget.MWidget, HemisphereWindowExt):
 
         if self.ui.checkShowAlignStar.isChecked():
             self.drawAlignmentStars(axes=axe)
-
         else:
             self.starsAlign = None
             self.starsAlignAnnotate = None
