@@ -24,6 +24,8 @@ from skyfield.api import wgs84
 
 # local import
 from base import transform
+from mountcontrol.convert import convertLatToAngle, convertLonToAngle
+from mountcontrol.convert import formatLatToText, formatLonToText
 
 
 class Mount(object):
@@ -215,18 +217,32 @@ class Mount(object):
         if location is None:
             return False
 
-        self.ui.siteLongitude.setText(self.formatLonToText(location.longitude))
-        self.ui.siteLatitude.setText(self.formatLatToText(location.latitude))
+        self.ui.siteLongitude.setText(formatLonToText(location.longitude))
+        self.ui.siteLatitude.setText(formatLatToText(location.latitude))
         self.ui.siteElevation.setText(str(location.elevation.m))
         return True
 
+    def checkMount(self):
+        """
+        :return:
+        """
+        msg = PyQt5.QtWidgets.QMessageBox
+        isMount = self.deviceStat.get('mount', False)
+        isObsSite = self.app.mount.obsSite is not None
+        isSetting = self.app.mount.setting is not None
+        if not isMount or not isObsSite or not isSetting:
+            msg.critical(self,
+                         'Error Message',
+                         'Value cannot be set when mount not connected !')
+            return False
+        else:
+            return True
+
     def changeTracking(self):
         """
         :return:
         """
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.obsSite is not None
-        if not isMount or not isData:
+        if not self.checkMount():
             return False
 
         obs = self.app.mount.obsSite
@@ -250,9 +266,7 @@ class Mount(object):
         """
         :return:
         """
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.obsSite is not None
-        if not isMount or not isData:
+        if not self.checkMount():
             return False
 
         obs = self.app.mount.obsSite
@@ -262,7 +276,6 @@ class Mount(object):
                 self.app.message.emit('Cannot unpark mount', 2)
             else:
                 self.app.message.emit('Mount unparked', 0)
-
         else:
             suc = obs.park()
             if not suc:
@@ -276,9 +289,7 @@ class Mount(object):
         """
         :return:
         """
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.setting is not None
-        if not isMount or not isData:
+        if not self.checkMount():
             return False
 
         sett = self.app.mount.setting
@@ -286,7 +297,6 @@ class Mount(object):
         if not suc:
             self.app.message.emit('Cannot set tracking to Lunar', 2)
             return False
-
         else:
             self.app.message.emit('Tracking set to Lunar', 0)
             return True
@@ -295,28 +305,22 @@ class Mount(object):
         """
         :return:
         """
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.setting is not None
-        if not isMount or not isData:
+        if not self.checkMount():
             return False
 
         sett = self.app.mount.setting
         suc = sett.setSiderealTracking()
         if not suc:
             self.app.message.emit('Cannot set tracking to Sidereal', 2)
-            return False
-
         else:
             self.app.message.emit('Tracking set to Sidereal', 0)
-            return True
+        return suc
 
     def setSolarTracking(self):
         """
         :return:
         """
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.setting is not None
-        if not isMount or not isData:
+        if not self.checkMount():
             return False
 
         sett = self.app.mount.setting
@@ -324,7 +328,6 @@ class Mount(object):
         if not suc:
             self.app.message.emit('Cannot set tracking to Solar', 2)
             return False
-
         else:
             self.app.message.emit('Tracking set to Solar', 0)
             return True
@@ -333,9 +336,7 @@ class Mount(object):
         """
         :return:
         """
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.obsSite is not None
-        if not isMount or not isData:
+        if not self.checkMount():
             return False
 
         obs = self.app.mount.obsSite
@@ -343,7 +344,6 @@ class Mount(object):
         if not suc:
             self.app.message.emit('Cannot flip mount', 2)
             return False
-
         else:
             self.app.message.emit('Mount flipped', 0)
             return True
@@ -352,9 +352,7 @@ class Mount(object):
         """
         :return:
         """
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.obsSite is not None
-        if not isMount or not isData:
+        if not self.checkMount():
             return False
 
         obs = self.app.mount.obsSite
@@ -362,7 +360,6 @@ class Mount(object):
         if not suc:
             self.app.message.emit('Cannot stop mount', 2)
             return False
-
         else:
             self.app.message.emit('Mount stopped', 0)
             return True
@@ -378,18 +375,11 @@ class Mount(object):
         """
         :return:    success as bool if value could be changed
         """
-        msg = PyQt5.QtWidgets.QMessageBox
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.setting is not None
-        if not isMount or not isData:
-            msg.critical(self,
-                         'Error Message',
-                         'Value cannot be set when mount not connected !')
+        if not self.checkMount():
             return False
 
         sett = self.app.mount.setting
         actValue = sett.meridianLimitTrack
-
         dlg = PyQt5.QtWidgets.QInputDialog()
         value, ok = dlg.getInt(self,
                                'Set Meridian Limit Track',
@@ -403,7 +393,7 @@ class Mount(object):
         if not ok:
             return False
         if sett.setMeridianLimitTrack(value):
-            self.app.message.emit(f'Meridian Limit Track: [{value}]', 0)
+            self.app.message.emit(f'Meridian Lim Track: [{value}]', 0)
             return True
         else:
             self.app.message.emit('Meridian Limit Track cannot be set', 2)
@@ -413,18 +403,11 @@ class Mount(object):
         """
         :return:    success as bool if value could be changed
         """
-        msg = PyQt5.QtWidgets.QMessageBox
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.setting is not None
-        if not isMount or not isData:
-            msg.critical(self,
-                         'Error Message',
-                         'Value cannot be set when mount not connected !')
+        if not self.checkMount():
             return False
 
         sett = self.app.mount.setting
         actValue = sett.meridianLimitSlew
-
         dlg = PyQt5.QtWidgets.QInputDialog()
         value, ok = dlg.getInt(self,
                                'Set Meridian Limit Slew',
@@ -448,18 +431,11 @@ class Mount(object):
         """
         :return:    success as bool if value could be changed
         """
-        msg = PyQt5.QtWidgets.QMessageBox
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.setting is not None
-        if not isMount or not isData:
-            msg.critical(self,
-                         'Error Message',
-                         'Value cannot be set when mount not connected !')
+        if not self.checkMount():
             return False
 
         sett = self.app.mount.setting
         actValue = sett.horizonLimitHigh
-
         dlg = PyQt5.QtWidgets.QInputDialog()
         value, ok = dlg.getInt(self,
                                'Set Horizon Limit High',
@@ -473,7 +449,7 @@ class Mount(object):
         if not ok:
             return False
         if sett.setHorizonLimitHigh(value):
-            self.app.message.emit(f'Horizon Limit High: [{value}]', 0)
+            self.app.message.emit(f'Horizon Limit High:  [{value}]', 0)
             return True
         else:
             self.app.message.emit('Horizon Limit High cannot be set', 2)
@@ -483,18 +459,11 @@ class Mount(object):
         """
         :return:    success as bool if value could be changed
         """
-        msg = PyQt5.QtWidgets.QMessageBox
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.setting is not None
-        if not isMount or not isData:
-            msg.critical(self,
-                         'Error Message',
-                         'Value cannot be set when mount not connected !')
+        if not self.checkMount():
             return False
 
         sett = self.app.mount.setting
         actValue = sett.horizonLimitLow
-
         dlg = PyQt5.QtWidgets.QInputDialog()
         value, ok = dlg.getInt(self,
                                'Set Horizon Limit Low',
@@ -508,7 +477,7 @@ class Mount(object):
         if not ok:
             return False
         if sett.setHorizonLimitLow(value):
-            self.app.message.emit(f'Horizon Limit Low: [{value}]', 0)
+            self.app.message.emit(f'Horizon Limit Low:   [{value}]', 0)
             return True
         else:
             self.app.message.emit('Horizon Limit Low cannot be set', 2)
@@ -518,18 +487,11 @@ class Mount(object):
         """
         :return:    success as bool if value could be changed
         """
-        msg = PyQt5.QtWidgets.QMessageBox
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.setting is not None
-        if not isMount or not isData:
-            msg.critical(self,
-                         'Error Message',
-                         'Value cannot be set when mount not connected !')
+        if not self.checkMount():
             return False
 
         sett = self.app.mount.setting
         actValue = sett.slewRate
-
         minRate = sett.slewRateMin
         maxRate = sett.slewRateMax
         dlg = PyQt5.QtWidgets.QInputDialog()
@@ -545,21 +507,45 @@ class Mount(object):
         if not ok:
             return False
         if sett.setSlewRate(value):
-            self.app.message.emit(f'Slew Rate: [{value}]', 0)
+            self.app.message.emit(f'Slew Rate:           [{value}]', 0)
             return True
         else:
             self.app.message.emit('Slew Rate cannot be set', 2)
             return False
 
+    def setLocationValues(self, lat=None, lon=None, elev=None):
+        """
+        :param lat:
+        :param lon:
+        :param elev:
+        :return:
+        """
+        obs = self.app.mount.obsSite
+        loc = obs.location
+        lat = loc.latitude if lat is None else lat
+        lon = loc.longitude if lon is None else lon
+        elev = loc.elevation.m if elev is None else elev
+
+        topo = wgs84.latlon(longitude_degrees=lon.degrees,
+                            latitude_degrees=lat.degrees,
+                            elevation_m=elev)
+
+        if self.app.deviceStat['mount']:
+            obs.setLocation(topo)
+            self.app.mount.getLocation()
+        else:
+            obs.location = topo
+            self.updateLocGUI(self.app.mount.obsSite)
+
+        t = f'Location set to:     [{lat.degrees:3.2f} deg, '
+        t += f'{lon.degrees:3.2f} deg, {elev:4.1f} m]'
+        self.app.message.emit(t, 0)
+        return True
+
     def setLongitude(self):
         """
         :return:    success as bool if value could be changed
         """
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.obsSite is not None
-        if not isMount or not isData:
-            return False
-
         obs = self.app.mount.obsSite
         if obs.location is None:
             return False
@@ -575,33 +561,14 @@ class Mount(object):
         if not ok:
             return False
 
-        value = self.convertLonToAngle(value)
-        if value is None:
-            return False
-
-        topo = wgs84.latlon(longitude_degrees=value.degrees,
-                            latitude_degrees=obs.location.latitude.degrees,
-                            elevation_m=obs.location.elevation.m)
-        obs.location = topo
-
-        if obs.setLongitude(value):
-            self.app.message.emit(f'Longitude set to:    '
-                                  f'[{value}]', 0)
-            self.app.mount.getLocation()
-            return True
-        else:
-            self.app.message.emit('Longitude cannot be set', 2)
-            return False
+        value = convertLonToAngle(value)
+        self.setLocationValues(lon=value)
+        return True
 
     def setLatitude(self):
         """
         :return:    success as bool if value could be changed
         """
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.obsSite is not None
-        if not isMount or not isData:
-            return False
-
         obs = self.app.mount.obsSite
         if obs.location is None:
             return False
@@ -616,35 +583,15 @@ class Mount(object):
         if not ok:
             return False
 
-        value = self.convertLatToAngle(value)
-        if value is None:
-            return False
-
-        topo = wgs84.latlon(longitude_degrees=obs.location.longitude.degrees,
-                            latitude_degrees=value.degrees,
-                            elevation_m=obs.location.elevation.m)
-        obs.location = topo
-
-        if obs.setLatitude(value):
-            self.app.message.emit(f'Latitude set to:     '
-                                  f'[{value}]', 0)
-            self.app.mount.getLocation()
-            return True
-        else:
-            self.app.message.emit('Latitude cannot be set', 2)
-            return False
+        value = convertLatToAngle(value)
+        self.setLocationValues(lat=value)
+        return True
 
     def setElevation(self):
         """
         :return:    success as bool if value could be changed
         """
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.obsSite is not None
-        if not isMount or not isData:
-            return False
-
         obs = self.app.mount.obsSite
-
         if obs.location is None:
             return False
 
@@ -660,34 +607,17 @@ class Mount(object):
         if not ok:
             return False
 
-        topo = wgs84.latlon(longitude_degrees=obs.location.longitude.degrees,
-                            latitude_degrees=obs.location.latitude.degrees,
-                            elevation_m=value)
-        obs.location = topo
-
-        if obs.setElevation(value):
-            self.app.message.emit(f'Elevation set to:    [{value}]', 0)
-            self.app.mount.getLocation()
-            return True
-        else:
-            self.app.message.emit('Elevation cannot be set', 2)
-            return False
+        self.setLocationValues(elev=value)
+        return True
 
     def setUnattendedFlip(self):
         """
         :return:    success as bool if value could be changed
         """
-        msg = PyQt5.QtWidgets.QMessageBox
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.setting is not None
-        if not isMount or not isData:
-            msg.critical(self,
-                         'Error Message',
-                         'Value cannot be set when mount not connected !')
+        if not self.checkMount():
             return False
 
         sett = self.app.mount.setting
-
         dlg = PyQt5.QtWidgets.QInputDialog()
         value, ok = dlg.getItem(self,
                                 'Set Unattended Flip',
@@ -700,7 +630,7 @@ class Mount(object):
             return False
         suc = sett.setUnattendedFlip(value == 'ON')
         if suc:
-            self.app.message.emit(f'Unattended flip set to [{value}]', 0)
+            self.app.message.emit(f'Unattended flip      [{value}]', 0)
         else:
             self.app.message.emit('Unattended flip cannot be set', 2)
         return suc
@@ -709,17 +639,10 @@ class Mount(object):
         """
         :return:    success as bool if value could be changed
         """
-        msg = PyQt5.QtWidgets.QMessageBox
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.setting is not None
-        if not isMount or not isData:
-            msg.critical(self,
-                         'Error Message',
-                         'Value cannot be set when mount not connected !')
+        if not self.checkMount():
             return False
 
         sett = self.app.mount.setting
-
         dlg = PyQt5.QtWidgets.QInputDialog()
         value, ok = dlg.getItem(self,
                                 'Set Dual Axis Tracking',
@@ -733,26 +656,19 @@ class Mount(object):
 
         suc = sett.setDualAxisTracking(value == 'ON')
         if suc:
-            self.app.message.emit(f'Dual axis tracking set to [{value}]', 0)
+            self.app.message.emit(f'DualAxis tracking    [{value}]', 0)
         else:
-            self.app.message.emit('Dual axis tracking cannot be set', 2)
+            self.app.message.emit('DualAxis tracking cannot be set', 2)
         return suc
 
     def setWOL(self):
         """
         :return:    success as bool if value could be changed
         """
-        msg = PyQt5.QtWidgets.QMessageBox
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.setting is not None
-        if not isMount or not isData:
-            msg.critical(self,
-                         'Error Message',
-                         'Value cannot be set when mount not connected !')
+        if not self.checkMount():
             return False
 
         sett = self.app.mount.setting
-
         dlg = PyQt5.QtWidgets.QInputDialog()
         value, ok = dlg.getItem(self,
                                 'Set Wake On Lan',
@@ -766,26 +682,19 @@ class Mount(object):
 
         suc = sett.setWOL(value == 'ON')
         if suc:
-            self.app.message.emit(f'WOL set to [{value}]', 0)
+            self.app.message.emit(f'Wake On Lan          [{value}]', 0)
         else:
-            self.app.message.emit('WOL cannot be set', 2)
+            self.app.message.emit('Wake On Lan cannot be set', 2)
         return suc
 
     def setRefraction(self):
         """
         :return:    success as bool if value could be changed
         """
-        msg = PyQt5.QtWidgets.QMessageBox
-        isMount = self.deviceStat.get('mount', False)
-        isData = self.app.mount.setting is not None
-        if not isMount or not isData:
-            msg.critical(self,
-                         'Error Message',
-                         'Value cannot be set when mount not connected !')
+        if not self.checkMount():
             return False
 
         sett = self.app.mount.setting
-
         dlg = PyQt5.QtWidgets.QInputDialog()
         value, ok = dlg.getItem(self,
                                 'Set Refraction Correction',
@@ -799,7 +708,7 @@ class Mount(object):
 
         suc = sett.setRefraction(value == 'ON')
         if suc:
-            self.app.message.emit(f'Refraction correction set to [{value}]', 0)
+            self.app.message.emit(f'Refraction corr.     [{value}]', 0)
         else:
             self.app.message.emit('Refraction correction cannot be set', 2)
         return suc
